@@ -4,12 +4,26 @@ from proxmoxer import ProxmoxAPI
 from pve_utils.config import settings
 from pve_utils.resources import ProxmoxNode
 
+from pve_utils.utils import pprint
+
 
 @click.command()
 @click.option(
-    "-N", "--node-name", required=True, type=str, help="Name of Proxmox Node."
+    "-N",
+    "--node-name",
+    default=settings.PROXMOX_NODE,
+    required=False,
+    type=str,
+    help="Name of Proxmox Node.",
+)
+@click.option(
+    "-H",
+    "--host-name",
+    default=settings.CT_HOST,
+    required=False,
+    type=str,
+    help="Name of CT.",
 )
-@click.option("-H", "--host-name", required=True, type=str, help="Name of CT.")
 @click.option(
     "-C",
     "--create",
@@ -28,7 +42,10 @@ def create_lxc(node_name: str, host_name: str, create: bool):
     )
 
     node_worker = ProxmoxNode(conn, node_name)
-    node_worker.get_lxc(host_name, create=create)
+    ct = node_worker.get_lxc(host_name, create=create)
+    if create:
+        pprint.info("Waiting for the CT to start")
+        ct.ssh_wait()
 
 
 if __name__ == "__main__":
